%define name 	mpqc
%define version 2.3.1
%define release %mkrel 13

%define	major		7
%define	libname		%mklibname SC %major
%define develname	%mklibname SC -d


Summary: 	Ab-inito chemistry program
Name: 		%name
Version: 	%version
Release: 	%release
License: 	GPLv2+
Group: 		Sciences/Chemistry
Source: 	http://prdownloads.sourceforge.net/mpqc/%name-%version.tar.bz2
URL: 		http://mpqc.org/
BuildRoot: 	%{_tmppath}/%name-buildroot
BuildRequires: 	flex bison lapack-devel
BuildRequires:	gcc-gfortran tk blas-devel mpich2-devel doxygen
BuildRequires:	autoconf
BuildConflicts:	gcc3.3-g77

%description
MPQC is the Massively Parallel Quantum Chemistry Program. It computes 
properties of atoms and molecules from first principles using the time 
independent Schrödinger equation. It runs on a wide range of architectures 
ranging from individual workstations to symmetric multiprocessors to 
massively parallel computers. Its design is object oriented, using the C++ 
programming language.

If you want to use this program on a distributed (parallel) network, you'll 
also have to install the libmpich package.

%package data
Summary:	Atom info and basis sets from MPQC
Group:		Sciences/Chemistry

%description data
Atom info and basis sets from MPQC.

%package html
Summary:	HTML documentation for MPQC
Group:		Sciences/Chemistry

%description html
This package contains the full documentation for MPQC that can be viewed
with a graphical browser like Mozilla.
 
%package -n molrender
Summary:	Graphical molecular rendering program
Group:		Sciences/Chemistry

%description -n molrender
This package graphically renders 3D molecules based on the output of 
computational chemistry packages like mpqc.

%package -n %libname
Summary:	Main libraries for %name
Group:		System/Libraries
Requires:	%name-data

%description -n %{libname}
This package contains the library needed to run programs dynamically linked 
with %libname, the scientific computing toolkit, based on mpqc computational 
chemistry package from Sandia Labs.

%package -n %{develname}
Summary:        Main libraries for %name
Group:          Development/C++
Requires:	%libname = %version
Provides:	libSC-devel
Provides:	SC-devel
Obsoletes:	%{mklibname SC 7 -d}

%description -n %{develname}
This package contains the library needed to run programs dynamically linked
with %libname, the scientific computing toolkit, based on mpqc computational
chemistry package from Sandia Labs.

%prep
%setup -q

%build
sed -i -e 's,prefix\/lib,prefix\/%{_lib},g' configure.in
autoconf
%configure2_5x --enable-shared --enable-threads
%make
cd doc
make
make man1
make man3

%install
rm -fr %{buildroot}
echo hello
make install installroot=%{buildroot}
make install_devel installroot=%{buildroot}
cp -r doc/man %buildroot/%{_datadir}

mkdir -p %{buildroot}%{_datadir}/applications
cat > %{buildroot}%{_datadir}/applications/mandriva-%{name}.desktop << EOF
[Desktop Entry]
Name=Molrender
Comment=Ab-inito chemistry program
Exec=%{_bindir}/tkmolrender
Icon=sciences_section
Terminal=false
Type=Application
Categories=Science;Chemistry;
EOF

# inelegant workaround to fix sc-config
sed -i -e 's:libSCdft.la libSCscf.la libSCwfn.la:libSCwfn.la libSCdft.la libSCscf.la:' %{buildroot}%{_bindir}/sc-config

%multiarch_binaries %{buildroot}%{_bindir}/sc-config

%clean
rm -rf %{buildroot}

%if %mdkversion < 200900
%post -n molrender
%{update_menus}
%endif

%if %mdkversion < 200900
%postun -n molrender
%{clean_menus}
%endif

%if %mdkversion < 200900
%post -n %{libname} -p /sbin/ldconfig
%endif
%if %mdkversion < 200900
%postun -n %{libname} -p /sbin/ldconfig
%endif

%files
%defattr(-,root,root)
%doc CHANGES CITATION LICENSE README
%{_bindir}/mpqc
%{_bindir}/chkmpqcout
%{_bindir}/scls
%{_bindir}/scpr
%{_bindir}/*run
%{_mandir}/man1/mpqc*
%{_mandir}/man1/scls*
%{_mandir}/man1/scpr*

%files data
%defattr(-,root,root)
%{_datadir}/%name

%files html
%defattr(-,root,root)
%doc doc/html

%files -n %{libname}
%defattr(-,root,root)
%{_libdir}/lib*.so.%{major}*

%files -n %{develname}
%defattr(-,root,root)
%{_bindir}/sc-*
%{multiarch_bindir}/sc-config
%{_libdir}/lib*.so
%{_libdir}/*.a
%{_libdir}/*.la
%{_includedir}/*
%{_mandir}/man1/sc-*
%{_mandir}/man3/*

%files -n molrender
%defattr(-,root,root)
%{_bindir}/molrender
%{_bindir}/tkmolrender
%{_datadir}/applications/mandriva-%{name}.desktop
%{_mandir}/man1/molrender*


%changelog
* Mon Dec 06 2010 Oden Eriksson <oeriksson@mandriva.com> 2.3.1-13mdv2011.0
+ Revision: 612946
- the mass rebuild of 2010.1 packages

* Fri Jan 15 2010 Jérôme Brenier <incubusss@mandriva.org> 2.3.1-12mdv2010.1
+ Revision: 491759
- drop P0 and use a workaround instead

* Thu Jan 14 2010 Jérôme Brenier <incubusss@mandriva.org> 2.3.1-11mdv2010.1
+ Revision: 491566
- revert the patch to r457268, the last one doesn't work
- fix License tag

* Thu Oct 15 2009 Guillaume Bedot <littletux@mandriva.org> 2.3.1-10mdv2010.0
+ Revision: 457789
+ rebuild (emptylog)

* Wed Oct 14 2009 Guillaume Bedot <littletux@mandriva.org> 2.3.1-9mdv2010.0
+ Revision: 457383
+ rebuild (emptylog)

* Wed Oct 14 2009 Guillaume Bedot <littletux@mandriva.org> 2.3.1-8mdv2010.0
+ Revision: 457268
- Fix linkage and sc-config

  + Funda Wang <fwang@mandriva.org>
    - first step to fix linkage

* Fri Sep 04 2009 Thierry Vignaud <tv@mandriva.org> 2.3.1-7mdv2010.0
+ Revision: 430105
- rebuild

* Tue Jul 08 2008 Funda Wang <fwang@mandriva.org> 2.3.1-6mdv2009.0
+ Revision: 232816
- fix rpmlint error

  + Pixel <pixel@mandriva.com>
    - rpm filetriggers deprecates update_menus/update_scrollkeeper/update_mime_database/update_icon_cache/update_desktop_database/post_install_gconf_schemas
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

* Mon Jan 07 2008 Adam Williamson <awilliamson@mandriva.org> 2.3.1-6mdv2008.1
+ Revision: 146330
- correct hardcoding of /usr/lib in configure.in: fixes sc-config on x86-64 and possibly other things
- new devel policy
- tidy spec

* Mon Jan 07 2008 Adam Williamson <awilliamson@mandriva.org> 2.3.1-5mdv2008.1
+ Revision: 146156
- rebuild to see if it fixes a problem with the library on x86-64

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Sun Nov 11 2007 Austin Acton <austin@mandriva.org> 2.3.1-4mdv2008.1
+ Revision: 107502
- adjust buildrequires
- rebuild for lapack

  + Thierry Vignaud <tv@mandriva.org>
    - kill desktop-file-validate's 'warning: key "Encoding" in group "Desktop Entry" is deprecated'

* Tue Aug 28 2007 Funda Wang <fwang@mandriva.org> 2.3.1-3mdv2008.0
+ Revision: 72332
- fix menu entry comment

* Thu May 10 2007 Austin Acton <austin@mandriva.org> 2.3.1-2mdv2008.0
+ Revision: 26068
- rebuild


* Sat Dec 09 2006 Emmanuel Andry <eandry@mandriva.org> 2.3.1-1mdv2007.0
+ Revision: 94308
- New version 2.3.1
  disable libtoolize
- xdg menu

* Sat Dec 09 2006 Emmanuel Andry <eandry@mandriva.org> 2.3.0-2mdv2007.1
+ Revision: 94198
- rebuild for missing requires
- Import mpqc

* Sun Dec 03 2006 Austin Acton <austin@mandriva.org> 2.3.0-1mdk
- 2.3.0
- man and html now in main tarball
- major 7
- fix my dumb idea to put data files into the library package

* Tue Sep 20 2005 Pascal Terjan <pterjan@mandriva.org> 2.2.3-4mdk
- Multiarch

* Tue Sep 20 2005 Pascal Terjan <pterjan@mandriva.org> 2.2.3-3mdk
- BUildConflicts gcc3.3-g77

* Tue Jul 26 2005 Austin Acton <austin@mandriva.org> 2.2.3-2mdk
- fix major
- drop libtoolize hack
- mklibname
- move headers to /usr/include/SC
- add man pages
- new URL
- configure 2.5
- split off html documentation
- compile against mpich
- add missing docs
- move some config utils to devel package

* Thu Jul 21 2005 Nicolas Lcureuil <neoclust@mandriva.org> 2.2.3-1mdk
- 2.2.3
- mkrel
- Fix BuildRequires
- Patch 0 : Fix Build For Gcc4

* Thu Jun 17 2004 Lenny Cartier <lenny@mandrakesoft.com> 2.2.2-1mdk
- 2.2.2

